@@ -6,13 +6,13 @@ from spb.functions import (
     plot3d,
     plot3d_parametric_line,
     plot3d_parametric_surface,
+    plot3d_implicit,
     plot_implicit,
     plot_polar,
     plot_geometry,
     plot_list,
     plot_piecewise
 )
-from spb.plot_data import get_plot_data, smart_plot
 from spb.vectors import plot_vector
 from spb.ccomplex.complex import (
     plot_complex, plot_complex_list,
