@@ -1,10 +1,10 @@
+import itertools
+import os
 from spb.defaults import cfg
 from spb.backends.base_backend import Plot
 from spb.backends.utils import get_seeds_points
 from sympy.external import import_module
-import itertools
 import warnings
-import os
 
 
 class PlotlyBackend(Plot):
@@ -21,43 +21,24 @@ class PlotlyBackend(Plot):
         - ``"equal"``: sets equal spacing on the axis of a 2D plot.
         - ``"cube"``, ``"auto"`` for 3D plots.
 
-    contour_kw : dict, optional
-        A dictionary of keywords/values which is passed to Plotly's contour
-        function to customize the appearance.
-        Refer to [#fn1]_ and [#fn2]_  to learn more about customization.
+    rendering_kw : dict, optional
+        A dictionary of keywords/values which is passed to Matplotlib's plot
+        functions to customize the appearance of lines, surfaces, images,
+        contours, quivers, streamlines...
+        To learn more about customization:
 
-    line_kw : dict, optional
-        A dictionary of keywords/values which is passed to Plotly's scatter
-        functions to customize the appearance.
-        Refer to [#fn3]_ and [#fn4]_ to learn more about customization.
-
-    quiver_kw : dict, optional
-        A dictionary of keywords/values which is passed to Plotly's quivers
-        function to customize the appearance.
-
-        - For 2D vector fields, default to: ``dict( scale = 0.075 )``.
-          Refer to [#fn5]_ for more options.
-        - For 3D vector fields, default to:
+        * Refer to [#fn1]_ and [#fn2]_ to customize contour plots.
+        * Refer to [#fn3]_ and [#fn4]_ to customize line plots.
+        * Refer to [#fn7]_ to customize surface plots.
+        * Refer to [#fn14]_ to customize implicit surface plots.
+        * Refer to [#fn5]_ to customize 2D quiver plots. Default to:
+          ``dict( scale = 0.075 )``.
+        * Refer to [#fn6]_ to customize 2D cone plots. Default to:
           ``dict( sizemode = "absolute", sizeref = 40 )``.
-          Refer [#fn6]_ for more options.
-
-    surface_kw : dict, optional
-        A dictionary of keywords/values to to customize the appearance which
-        is passed to:
-
-        - Plotly's Surface function for 3D surface and parametric surface
-          plots. Refer to [#fn7]_ for more options.
-        - Plotly's Isosurface function for 3D implicit plots. Refer to [#fn14]_
-          for more options.
-
-    stream_kw : dict, optional
-        A dictionary of keywords/values which is passed to Plotly's
-        streamlines function to customize the appearance.
-
-        - For 2D vector fields, defaul to: ``dict( arrow_scale = 0.15 )``.
-          Refer to [#fn8]_ for more options.
-        - For 3D vector fields, default to: ``dict( sizeref = 0.3 )``.
-          Refer to [#fn9]_ for more options.
+        * Refer to [#fn8]_ to customize 2D streamlines plots. Defaul to:
+          ``dict( arrow_scale = 0.15 )``.
+        * Refer to [#fn9]_ to customize 3D streamlines plots. Defaul to:
+          ``dict( sizeref = 0.3 )``.
 
     theme : str, optional
         Set the theme. Default to ``"plotly_dark"``. Find more Plotly themes at
@@ -183,11 +164,13 @@ class PlotlyBackend(Plot):
 
     def _set_piecewise_color(self, s, color):
         """Set the color to the given series"""
-        s.rendering_kw["line_color"] = color
-        if not s.is_filled:
-            s.rendering_kw["marker"] = dict(
-                color="#E5ECF6",
-                line=dict(color=color))
+        if "line_color" not in s.rendering_kw:
+            # only set the color if the user didn't do that already
+            s.rendering_kw["line_color"] = color
+            if not s.is_filled:
+                s.rendering_kw["marker"] = dict(
+                    color="#E5ECF6",
+                    line=dict(color=color))
 
     @staticmethod
     def _do_sum_kwargs(p1, p2):
@@ -224,9 +207,11 @@ class PlotlyBackend(Plot):
             y=0,
         )
 
-    def _solid_colorscale(self):
+    def _solid_colorscale(self, s):
         # create a solid color to be used when s.use_cm=False
-        col = next(self._cl)
+        col = s.line_color
+        if col is None:
+            col = next(self._cl)
         return [[0, col], [1, col]]
 
     def _process_series(self, series):
@@ -266,9 +251,10 @@ class PlotlyBackend(Plot):
                     mode = "lines+markers" if not s.is_point else "markers"
                     if (not s.is_point) and (not s.use_cm):
                         mode = "lines"
+                    color = next(self._cl) if s.line_color is None else s.line_color
                     lkw = dict(
                         name=s.get_label(self._use_latex),
-                        line_color=next(self._cl),
+                        line_color=color,
                         mode=mode,
                         marker=dict(
                             color=param,
@@ -292,7 +278,7 @@ class PlotlyBackend(Plot):
                     self._fig.add_trace(go.Scatter(x=x, y=y, **kw))
                 else:
                     x, y = s.get_data()
-                    color = next(self._cl)
+                    color = next(self._cl) if s.line_color is None else s.line_color
                     lkw = dict(
                         name=s.get_label(self._use_latex),
                         mode="lines" if not s.is_point else "markers",
@@ -331,7 +317,7 @@ class PlotlyBackend(Plot):
                             colorscale=(
                                 next(self._cm)
                                 if s.use_cm
-                                else self._solid_colorscale()
+                                else self._solid_colorscale(s)
                             ),
                             color=param,
                             showscale=self.legend and s.use_cm,
@@ -342,20 +328,20 @@ class PlotlyBackend(Plot):
                     lkw = dict(
                         name=s.get_label(self._use_latex),
                         mode="markers",
-                        line_color=next(self._cl))
+                        line_color=next(self._cl) if s.line_color is None else s.line_color)
                 kw = merge({}, lkw, s.rendering_kw)
                 self._fig.add_trace(go.Scatter3d(x=x, y=y, z=z, **kw))
 
             elif s.is_3Dsurface and (not s.is_domain_coloring) and (not s.is_implicit):
                 if not s.is_parametric:
                     xx, yy, zz = s.get_data()
-                    surfacecolor = s.color_func(xx, yy, zz)
+                    surfacecolor = s.eval_color_func(xx, yy, zz)
                 else:
                     xx, yy, zz, uu, vv = s.get_data()
-                    surfacecolor = s.color_func(xx, yy, zz, uu, vv)
+                    surfacecolor = s.eval_color_func(xx, yy, zz, uu, vv)
 
                 # create a solid color to be used when s.use_cm=False
-                col = next(self._cl)
+                col = next(self._cl) if s.surface_color is None else s.surface_color
                 colorscale = [[0, col], [1, col]]
                 colormap = next(self._cm)
                 skw = dict(
@@ -442,7 +428,7 @@ class PlotlyBackend(Plot):
                             colorscale=(
                                 next(self._cm)
                                 if s.use_cm
-                                else self._solid_colorscale()
+                                else self._solid_colorscale(s)
                             ),
                             sizeref=0.3,
                             showscale=self.legend and s.use_cm,
@@ -658,10 +644,10 @@ class PlotlyBackend(Plot):
                 elif s.is_3Dsurface and (not s.is_domain_coloring) and (not s.is_implicit):
                     if not s.is_parametric:
                         x, y, z = s.get_data()
-                        surfacecolor = s.color_func(x, y, z)
+                        surfacecolor = s.eval_color_func(x, y, z)
                     else:
                         x, y, z, u, v = s.get_data()
-                        surfacecolor = s.color_func(x, y, z, u, v)
+                        surfacecolor = s.eval_color_func(x, y, z, u, v)
                         self.fig.data[i]["x"] = x
                         self.fig.data[i]["y"] = y
 
