@@ -1,12 +1,13 @@
 from spb.defaults import cfg
 from sympy import Tuple, sympify, Expr, Dummy, S
 from sympy.matrices.dense import DenseMatrix
+from sympy.physics.mechanics import Vector as MechVector
 from sympy.vector import Vector
 from sympy.vector.operators import _get_coord_systems
 from sympy.core.relational import Relational
 from sympy.logic.boolalg import BooleanFunction
 from sympy.external import import_module
-
+import warnings
 
 def _create_ranges(exprs, ranges, npar, label="", params=None):
     """This function does two things:
@@ -36,7 +37,9 @@ def _create_ranges(exprs, ranges, npar, label="", params=None):
     """
 
     get_default_range = lambda symbol: Tuple(symbol, cfg["plot_range"]["min"], cfg["plot_range"]["max"])
-    free_symbols = set().union(*[e.free_symbols for e in exprs])
+    free_symbols = set()
+    if all(not callable(e) for e in exprs):
+        free_symbols = free_symbols.union(*[e.free_symbols for e in exprs])
 
     if params is not None:
         free_symbols = free_symbols.difference(params.keys())
@@ -82,28 +85,6 @@ def _create_ranges(exprs, ranges, npar, label="", params=None):
     return ranges
 
 
-def _check_interactive_fs(exprs, ranges, label, params):
-    """ Checks if there are enogh parameters and free symbols in order to
-    build the interactive series.
-    """
-    # from the expression's free symbols, remove the ones used in
-    # the parameters and the ranges
-    fs = set().union(*[e.free_symbols for e in exprs])
-    fs = fs.difference(params.keys())
-    if ranges is not None:
-        fs = fs.difference([r[0] for r in ranges])
-
-    if len(fs) > 0:
-        raise ValueError(
-            "Incompatible expression and parameters.\n"
-            + "Expression: {}\n".format(
-                (exprs, ranges, label) if ranges is not None else (exprs, label))
-            + "params: {}\n".format(params)
-            + "Specify what these symbols represent: {}\n".format(fs)
-            + "Are they ranges or parameters?"
-        )
-
-
 def _check_arguments(args, nexpr, npar, **kwargs):
     """Checks the arguments and converts into tuples of the
     form (exprs, ranges, name_expr).
@@ -204,7 +185,9 @@ def _check_arguments(args, nexpr, npar, **kwargs):
             rend_kw = rendering_kw if len(rend_kw) == 0 else rend_kw[0]
 
             arg = arg[:nexpr]
-            free_symbols = set().union(*[a.free_symbols for a in arg])
+            free_symbols = set()
+            if all(not callable(a) for a in arg):
+                free_symbols = free_symbols.union(*[a.free_symbols for a in arg])
             if len(r) != npar:
                 r = _create_ranges(arg, r, npar, "", params)
 
@@ -228,7 +211,7 @@ def _plot_sympify(args):
     for i, a in enumerate(args):
         if isinstance(a, (list, tuple)):
             args[i] = Tuple(*_plot_sympify(a), sympify=False)
-        elif not isinstance(a, (str, dict)):
+        elif not (isinstance(a, (str, dict, MechVector)) or callable(a)):
             args[i] = sympify(a)
     return args
 
@@ -303,12 +286,6 @@ def _unpack_args_extended(*args, matrices=False, fill_ranges=True):
     """
     exprs, ranges, label, rendering_kw = _unpack_args(*args)
 
-    if label == "":
-        if len(exprs) == 1:
-            label = str(exprs[0])
-        else:
-            label = str(tuple(exprs))
-
     if matrices and (len(exprs) == 1):
         if isinstance(exprs[0], (list, tuple, Tuple, DenseMatrix)):
             exprs = list(exprs[0])
@@ -376,6 +353,8 @@ def _split_vector(expr, ranges, fill_ranges=True):
     if isinstance(expr, Vector):
         N = list(_get_coord_systems(expr))[0]
         expr = expr.to_matrix(N)
+    elif isinstance(expr, MechVector):
+        expr = expr.args[0][0]
     elif not isinstance(expr, (DenseMatrix, list, tuple, Tuple)):
         raise TypeError(
             "The provided expression must be a symbolic vector, or a "
@@ -390,7 +369,9 @@ def _split_vector(expr, ranges, fill_ranges=True):
 
     if fill_ranges:
         ranges = list(ranges)
-        fs = set().union(*[e.free_symbols for e in expr])
+        fs = set()
+        if all(not callable(e) for e in expr):
+            fs = fs.union(*[e.free_symbols for e in expr])
         if len(ranges) < len(fs):
             fs_ranges = set().union([r[0] for r in ranges])
             for s in fs:
@@ -408,6 +389,115 @@ def _split_vector(expr, ranges, fill_ranges=True):
 
 def _instantiate_backend(Backend, *series, **kwargs):
     p = Backend(*series, **kwargs)
+    _validate_kwargs(p, **kwargs)
+
     if kwargs.get("show", True):
         p.show()
     return p
+
+
+def _validate_kwargs(backend_obj, **kwargs):
+    """Find the user-provided keywords arguments that might contain spelling
+    errors and informs the user of possible alternatives.
+
+    Parameters
+    ==========
+    backend_obj : Plot
+        An instance of the Plot class
+
+    Notes
+    =====
+    To keep development "agile", I extensively used ``**kwargs`` everywhere.
+    The problem is that there are "multiple levels" of keyword arguments:
+
+    * some keyword arguments get intercepted at the plotting function level.
+      Think for example to ``scalar`` in ``plot_vector``, or ``sum_bound`` in
+      ``plot``.
+    * some plotting function might insert useful keyword arguments, for example
+      ``real``, ``imag``, etc., on complex-related functions.
+    * many of the keyword arguments get passed down to the Series and to
+      the Backend classes.
+
+    There are many approaches to tackle keyword arguments validation:
+
+    1. Replace **kwargs everywhere with the actual expected keywords.
+       This is very time consuming and hard to maintain as the module gets
+       developed even further. Morover, Python will raise an error everytime
+       something get mispelled, which I think is annoying.
+    2. Perform "multiple levels" of keyword validation, at a plotting function
+       level (on each function), at a series level and at a backend level.
+       Again, time consuming.
+    3. The laziest and most simple approach I could think of: create the
+       ``_allowed_keys`` attribute on Series and Backend classes. Implement
+       this function to perform some validation. It is definitely not as good
+       as the previous approaches, in particular:
+
+       * the validation is actually done after the creation of Series and
+         Backend. This is not a problem as the validation is only meant to show
+         a warning message.
+       * needs to be careful when modifying Series and Backend, as the
+         ``_allowed_keys`` attribute must be update.
+       * function-level keyword arguments must be listed inside this function.
+         Again, not so great in terms of further development.
+
+       But it's a quick approach and surely better than nothing.
+    """
+    # find the user-provided keywords arguments that might contain
+    # spelling errors and inform the user of possible alternatives.
+    allowed_keys = set(backend_obj._allowed_keys)
+    for s in backend_obj.series:
+        allowed_keys = allowed_keys.union(s._allowed_keys)
+    # some functions injects the following keyword arguments that will be
+    # processed by other functions before instantion of Series and Backend.
+    allowed_keys = allowed_keys.union([
+        "is_interactive", "abs", "absarg", "arg", "real", "imag",
+        "is_complex", "is_vector", "slice", "threed", "sum_bound", "n",
+        "phaseres", "is_polar", "label"
+    ])
+    # params is a keyword argument that is also checked before instantion of
+    # Series and Backend.
+    allowed_keys = allowed_keys.union(["params", "layout", "ncols",
+        "use_latex", "throttled", "servable", "custom_css", "pane_kw",
+        "is_iplot"])
+    user_provided_keys = set(kwargs.keys())
+    unused_keys = user_provided_keys.difference(allowed_keys)
+    if len(unused_keys) > 0:
+        msg = "\nThe following keyword arguments are unused.\n"
+        for k in unused_keys:
+            possible_match = find_closest_string(k, allowed_keys)
+            msg += "* '%s'" % k
+            msg += ": did you mean '%s'?\n" % possible_match
+        warnings.warn(msg)
+        # this returns helps with tests
+        return msg
+
+
+# taken from
+# https://en.wikibooks.org/wiki/Algorithm_Implementation/Strings/Levenshtein_distance#Python
+def levenshtein(s1, s2):
+    if len(s1) < len(s2):
+        return levenshtein(s2, s1)  # len(s1) >= len(s2)
+    if len(s2) == 0:
+        return len(s1)
+    previous_row = range(len(s2) + 1)
+    for i, c1 in enumerate(s1):
+        current_row = [i + 1]
+        for j, c2 in enumerate(s2):
+            # j+1 instead of j since previous_row and current_row are one character longer
+            # than s2
+            insertions = previous_row[j + 1] + 1
+            deletions = current_row[j] + 1
+            substitutions = previous_row[j] + (c1 != c2)
+            current_row.append(min(insertions, deletions, substitutions))
+        previous_row = current_row
+    return previous_row[-1]
+
+
+# taken from plotly.py/packages/python/plotly/_plotly_utils/utils.py
+def find_closest_string(string, strings):
+    def _key(s):
+        # sort by levenshtein distance and lexographically to maintain a stable
+        # sort for different keys with the same levenshtein distance
+        return (levenshtein(s, string), s)
+
+    return sorted(strings, key=_key)[0]
